
## CATO-CLI - mutation.policy.antiMalwareFileHash.publishPolicyRevision:
[Click here](https://api.catonetworks.com/documentation/#mutation-mutation.policy.antiMalwareFileHash.publishPolicyRevision) for documentation on this operation.

### Usage for mutation.policy.antiMalwareFileHash.publishPolicyRevision:

`catocli mutation policy antiMalwareFileHash publishPolicyRevision -h`

`catocli mutation policy antiMalwareFileHash publishPolicyRevision <json>`

`catocli mutation policy antiMalwareFileHash publishPolicyRevision "$(cat < mutation.policy.antiMalwareFileHash.publishPolicyRevision.json)"`

`catocli mutation policy antiMalwareFileHash publishPolicyRevision '{"antiMalwareFileHashPolicyMutationInput":{"policyMutationRevisionInput":{"id":"id"}},"policyPublishRevisionInput":{"description":"string","name":"string"}}'`


#### Operation Arguments for mutation.policy.antiMalwareFileHash.publishPolicyRevision ####

`accountId` [ID] - (required) N/A    
`antiMalwareFileHashPolicyMutationInput` [AntiMalwareFileHashPolicyMutationInput] - (required) N/A    
`policyPublishRevisionInput` [PolicyPublishRevisionInput] - (required) N/A    
